pygeodesy.ellipsoidalBaseDI

Package pygeodesy :: Module ellipsoidalBaseDI |
[frames] | no frames]

# Module ellipsoidalBaseDI

(INTERNAL) Private, ellipsoidal Direct/Inverse geodesy base class `LatLonEllipsoidalBaseDI` and functions.

Version: 25.05.23

Classes
| LatLonEllipsoidalBaseDI (INTERNAL) Base class for `ellipsoidal*.LatLon` classes with overloaded `Direct` and `Inverse` methods.

Functions
intersecant2(center, circle, point, other, **exact_height_wrap_tol) Compute the intersections of a circle and a geodesic given as two points or as a point and (forward) bearing. |

Variables
| __all__ = `_ALL_LAZY.ellipsoidalBaseDI`

Function Details

### intersecant2 (center, circle, point, other, **exact_height_wrap_tol) |
Compute the intersections of a circle and a geodesic given as two points or as a point and (forward) bearing. Arguments: `center` - Center of the circle (`LatLon`). `circle` - Radius of the circle (`meter`, conventionally) or a point on the circle (`LatLon`, as `center`). `point` - A point of the geodesic (`LatLon`, as `center`). `other` - An other point of the geodesic (`LatLon`, as `center`) or the (forward) bearing at the `point` (compass `degrees`). `exact_height_wrap_tol` - Optional keyword arguments `exact=False`, `height=None`, `wrap=False` and `tol`, see method intersecant2. Raises: `NotImplementedError` - Method `intersecant2` not available. `TypeError` - If `center`, `point` or `circle` or `other` points not ellipsoidal or not compatible with `center`. See Also: Method `LatLon.intersecant2` of class ellipsoidalExact.LatLon, ellipsoidalKarney.LatLon or ellipsoidalVincenty.LatLon.